# coding: utf-8

# flake8: noqa
"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from culebratester_client.models.any_value import AnyValue
from culebratester_client.models.boolean_response import BooleanResponse
from culebratester_client.models.click_body import ClickBody
from culebratester_client.models.culebra_info import CulebraInfo
from culebratester_client.models.current_package_name import CurrentPackageName
from culebratester_client.models.display_height import DisplayHeight
from culebratester_client.models.display_real_size import DisplayRealSize
from culebratester_client.models.display_rotation_enum import DisplayRotationEnum
from culebratester_client.models.display_rotation_response import DisplayRotationResponse
from culebratester_client.models.display_size_dp import DisplaySizeDp
from culebratester_client.models.display_width import DisplayWidth
from culebratester_client.models.help import Help
from culebratester_client.models.inline_response200 import InlineResponse200
from culebratester_client.models.last_traversed_text import LastTraversedText
from culebratester_client.models.locale import Locale
from culebratester_client.models.number_response import NumberResponse
from culebratester_client.models.object_ref import ObjectRef
from culebratester_client.models.pattern import Pattern
from culebratester_client.models.perform_two_pointer_gesture_body import PerformTwoPointerGestureBody
from culebratester_client.models.pixel import Pixel
from culebratester_client.models.point import Point
from culebratester_client.models.product_name import ProductName
from culebratester_client.models.selector import Selector
from culebratester_client.models.status_response import StatusResponse
from culebratester_client.models.string_response import StringResponse
from culebratester_client.models.swipe_body import SwipeBody
from culebratester_client.models.text import Text
from culebratester_client.models.timeout import Timeout
from culebratester_client.models.window_hierarchy import WindowHierarchy
from culebratester_client.models.window_hierarchy_child import WindowHierarchyChild



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PerformTwoPointerGestureBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_point1': 'Point',
        'start_point2': 'Point',
        'end_point1': 'Point',
        'end_point2': 'Point',
        'steps': 'int'
    }

    attribute_map = {
        'start_point1': 'startPoint1',
        'start_point2': 'startPoint2',
        'end_point1': 'endPoint1',
        'end_point2': 'endPoint2',
        'steps': 'steps'
    }

    def __init__(self, start_point1=None, start_point2=None, end_point1=None, end_point2=None, steps=None):  # noqa: E501
        """PerformTwoPointerGestureBody - a model defined in Swagger"""  # noqa: E501
        self._start_point1 = None
        self._start_point2 = None
        self._end_point1 = None
        self._end_point2 = None
        self._steps = None
        self.discriminator = None
        self.start_point1 = start_point1
        self.start_point2 = start_point2
        self.end_point1 = end_point1
        self.end_point2 = end_point2
        self.steps = steps

    @property
    def start_point1(self):
        """Gets the start_point1 of this PerformTwoPointerGestureBody.  # noqa: E501


        :return: The start_point1 of this PerformTwoPointerGestureBody.  # noqa: E501
        :rtype: Point
        """
        return self._start_point1

    @start_point1.setter
    def start_point1(self, start_point1):
        """Sets the start_point1 of this PerformTwoPointerGestureBody.


        :param start_point1: The start_point1 of this PerformTwoPointerGestureBody.  # noqa: E501
        :type: Point
        """
        if start_point1 is None:
            raise ValueError("Invalid value for `start_point1`, must not be `None`")  # noqa: E501

        self._start_point1 = start_point1

    @property
    def start_point2(self):
        """Gets the start_point2 of this PerformTwoPointerGestureBody.  # noqa: E501


        :return: The start_point2 of this PerformTwoPointerGestureBody.  # noqa: E501
        :rtype: Point
        """
        return self._start_point2

    @start_point2.setter
    def start_point2(self, start_point2):
        """Sets the start_point2 of this PerformTwoPointerGestureBody.


        :param start_point2: The start_point2 of this PerformTwoPointerGestureBody.  # noqa: E501
        :type: Point
        """
        if start_point2 is None:
            raise ValueError("Invalid value for `start_point2`, must not be `None`")  # noqa: E501

        self._start_point2 = start_point2

    @property
    def end_point1(self):
        """Gets the end_point1 of this PerformTwoPointerGestureBody.  # noqa: E501


        :return: The end_point1 of this PerformTwoPointerGestureBody.  # noqa: E501
        :rtype: Point
        """
        return self._end_point1

    @end_point1.setter
    def end_point1(self, end_point1):
        """Sets the end_point1 of this PerformTwoPointerGestureBody.


        :param end_point1: The end_point1 of this PerformTwoPointerGestureBody.  # noqa: E501
        :type: Point
        """
        if end_point1 is None:
            raise ValueError("Invalid value for `end_point1`, must not be `None`")  # noqa: E501

        self._end_point1 = end_point1

    @property
    def end_point2(self):
        """Gets the end_point2 of this PerformTwoPointerGestureBody.  # noqa: E501


        :return: The end_point2 of this PerformTwoPointerGestureBody.  # noqa: E501
        :rtype: Point
        """
        return self._end_point2

    @end_point2.setter
    def end_point2(self, end_point2):
        """Sets the end_point2 of this PerformTwoPointerGestureBody.


        :param end_point2: The end_point2 of this PerformTwoPointerGestureBody.  # noqa: E501
        :type: Point
        """
        if end_point2 is None:
            raise ValueError("Invalid value for `end_point2`, must not be `None`")  # noqa: E501

        self._end_point2 = end_point2

    @property
    def steps(self):
        """Gets the steps of this PerformTwoPointerGestureBody.  # noqa: E501

        the number of steps for the gesture. Steps are injected about 5 milliseconds apart, so 100 steps may take around 0.5 seconds to complete.  # noqa: E501

        :return: The steps of this PerformTwoPointerGestureBody.  # noqa: E501
        :rtype: int
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this PerformTwoPointerGestureBody.

        the number of steps for the gesture. Steps are injected about 5 milliseconds apart, so 100 steps may take around 0.5 seconds to complete.  # noqa: E501

        :param steps: The steps of this PerformTwoPointerGestureBody.  # noqa: E501
        :type: int
        """
        if steps is None:
            raise ValueError("Invalid value for `steps`, must not be `None`")  # noqa: E501

        self._steps = steps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PerformTwoPointerGestureBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PerformTwoPointerGestureBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import culebratester_client
from culebratester_client.api.default_api import DefaultApi  # noqa: E501
from culebratester_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_configurator_get_wait_for_idle_timeout_get(self):
        """Test case for configurator_get_wait_for_idle_timeout_get

        Gets the current timeout used for waiting for the user interface to go into an idle state.  # noqa: E501
        """
        pass

    def test_configurator_set_wait_for_idle_timeout_get(self):
        """Test case for configurator_set_wait_for_idle_timeout_get

        Sets the timeout for waiting for the user interface to go into an idle state before starting a uiautomator action.  # noqa: E501
        """
        pass

    def test_culebra_help_api_get(self):
        """Test case for culebra_help_api_get

        Gets help  # noqa: E501
        """
        pass

    def test_culebra_info_get(self):
        """Test case for culebra_info_get

        Gets information about this app.  # noqa: E501
        """
        pass

    def test_culebra_quit_get(self):
        """Test case for culebra_quit_get

        Quits culebra server.  # noqa: E501
        """
        pass

    def test_device_display_real_size_get(self):
        """Test case for device_display_real_size_get

        Gets display real size.  # noqa: E501
        """
        pass

    def test_device_dumpsys_get(self):
        """Test case for device_dumpsys_get

        """
        pass

    def test_device_locale_get(self):
        """Test case for device_locale_get

        """
        pass

    def test_device_locale_post(self):
        """Test case for device_locale_post

        """
        pass

    def test_device_wait_for_new_toast_get(self):
        """Test case for device_wait_for_new_toast_get

        Waits for a new Toast.  # noqa: E501
        """
        pass

    def test_object_store_clear_get(self):
        """Test case for object_store_clear_get

        Clears all the objects in store.  # noqa: E501
        """
        pass

    def test_object_store_list_get(self):
        """Test case for object_store_list_get

        Lists the objects in store.  # noqa: E501
        """
        pass

    def test_object_store_remove_get(self):
        """Test case for object_store_remove_get

        Removes an object.  # noqa: E501
        """
        pass

    def test_target_context_start_activity_get(self):
        """Test case for target_context_start_activity_get

        Starts an Activity.  # noqa: E501
        """
        pass

    def test_ui_device_clear_last_traversed_text_get(self):
        """Test case for ui_device_clear_last_traversed_text_get

        Clears the text from the last UI traversal event.  # noqa: E501
        """
        pass

    def test_ui_device_click_get(self):
        """Test case for ui_device_click_get

        Clicks at the specified location.  # noqa: E501
        """
        pass

    def test_ui_device_click_post(self):
        """Test case for ui_device_click_post

        Clicks at the specified locations.  # noqa: E501
        """
        pass

    def test_ui_device_current_package_name_get(self):
        """Test case for ui_device_current_package_name_get

        Gets the current package name.  # noqa: E501
        """
        pass

    def test_ui_device_display_height_get(self):
        """Test case for ui_device_display_height_get

        Gets the display height.  # noqa: E501
        """
        pass

    def test_ui_device_display_rotation_get(self):
        """Test case for ui_device_display_rotation_get

        Gets the display rotation.  # noqa: E501
        """
        pass

    def test_ui_device_display_size_dp_get(self):
        """Test case for ui_device_display_size_dp_get

        Gets the display size in DP.  # noqa: E501
        """
        pass

    def test_ui_device_display_width_get(self):
        """Test case for ui_device_display_width_get

        Gets the display width.  # noqa: E501
        """
        pass

    def test_ui_device_drag_get(self):
        """Test case for ui_device_drag_get

        Performs a swipe from one coordinate to another coordinate.  # noqa: E501
        """
        pass

    def test_ui_device_dump_window_hierarchy_get(self):
        """Test case for ui_device_dump_window_hierarchy_get

        Dumps the window hierarchy.  # noqa: E501
        """
        pass

    def test_ui_device_find_object_get(self):
        """Test case for ui_device_find_object_get

        Finds an object.  # noqa: E501
        """
        pass

    def test_ui_device_find_object_post(self):
        """Test case for ui_device_find_object_post

        Finds an object.  # noqa: E501
        """
        pass

    def test_ui_device_find_objects_get(self):
        """Test case for ui_device_find_objects_get

        Finds *all* objects that match the selector criteria.  # noqa: E501
        """
        pass

    def test_ui_device_find_objects_post(self):
        """Test case for ui_device_find_objects_post

        Finds *all* objects.  # noqa: E501
        """
        pass

    def test_ui_device_freeze_rotation_get(self):
        """Test case for ui_device_freeze_rotation_get

        Disables the sensors and freezes the device rotation at its current rotation state.  # noqa: E501
        """
        pass

    def test_ui_device_has_object_get(self):
        """Test case for ui_device_has_object_get

        Returns whether there is a match for the given selector criteria.  # noqa: E501
        """
        pass

    def test_ui_device_has_object_post(self):
        """Test case for ui_device_has_object_post

        Returns whether there is a match for the given selector criteria.  # noqa: E501
        """
        pass

    def test_ui_device_is_natural_orientation_get(self):
        """Test case for ui_device_is_natural_orientation_get

        Check if the device is in its natural orientation.  # noqa: E501
        """
        pass

    def test_ui_device_is_screen_on_get(self):
        """Test case for ui_device_is_screen_on_get

        Checks the power manager if the screen is ON.  # noqa: E501
        """
        pass

    def test_ui_device_last_traversed_text_get(self):
        """Test case for ui_device_last_traversed_text_get

        Retrieves the text from the last UI traversal event received.  # noqa: E501
        """
        pass

    def test_ui_device_pixel_get(self):
        """Test case for ui_device_pixel_get

        Gets a pixel from device screen.  # noqa: E501
        """
        pass

    def test_ui_device_press_back_get(self):
        """Test case for ui_device_press_back_get

        Simulates a short press on the BACK button.  # noqa: E501
        """
        pass

    def test_ui_device_press_d_pad_center_get(self):
        """Test case for ui_device_press_d_pad_center_get

        Simulates a short press on the CENTER button.  # noqa: E501
        """
        pass

    def test_ui_device_press_d_pad_down_get(self):
        """Test case for ui_device_press_d_pad_down_get

        Simulates a short press on the DOWN button.  # noqa: E501
        """
        pass

    def test_ui_device_press_d_pad_left_get(self):
        """Test case for ui_device_press_d_pad_left_get

        Simulates a short press on the LEFT button.  # noqa: E501
        """
        pass

    def test_ui_device_press_d_pad_right_get(self):
        """Test case for ui_device_press_d_pad_right_get

        Simulates a short press on the RIGHT button.  # noqa: E501
        """
        pass

    def test_ui_device_press_d_pad_up_get(self):
        """Test case for ui_device_press_d_pad_up_get

        Simulates a short press on the UP button.  # noqa: E501
        """
        pass

    def test_ui_device_press_delete_get(self):
        """Test case for ui_device_press_delete_get

        Simulates a short press on the DELETE key.  # noqa: E501
        """
        pass

    def test_ui_device_press_enter_get(self):
        """Test case for ui_device_press_enter_get

        Simulates a short press on the ENTER key.  # noqa: E501
        """
        pass

    def test_ui_device_press_home_get(self):
        """Test case for ui_device_press_home_get

        Simulates a short press on the HOME button.  # noqa: E501
        """
        pass

    def test_ui_device_press_key_code_get(self):
        """Test case for ui_device_press_key_code_get

        Simulates a short press using a key code.  # noqa: E501
        """
        pass

    def test_ui_device_press_recent_apps_get(self):
        """Test case for ui_device_press_recent_apps_get

        Simulates a short press on the Recent Apps button.  # noqa: E501
        """
        pass

    def test_ui_device_product_name_get(self):
        """Test case for ui_device_product_name_get

        Retrieves the product name of the device.  # noqa: E501
        """
        pass

    def test_ui_device_screenshot_get(self):
        """Test case for ui_device_screenshot_get

        Gets the device screenshot.  # noqa: E501
        """
        pass

    def test_ui_device_swipe_get(self):
        """Test case for ui_device_swipe_get

        Performs a swipe.  # noqa: E501
        """
        pass

    def test_ui_device_swipe_post(self):
        """Test case for ui_device_swipe_post

        Performs a swipe between points in the Point array.  # noqa: E501
        """
        pass

    def test_ui_device_unfreeze_rotation_get(self):
        """Test case for ui_device_unfreeze_rotation_get

        Re-enables the sensors and un-freezes the device rotation allowing its contents to rotate with the device physical rotation  # noqa: E501
        """
        pass

    def test_ui_device_wait_for_idle_get(self):
        """Test case for ui_device_wait_for_idle_get

        Waits for the current application to idle.  # noqa: E501
        """
        pass

    def test_ui_device_wait_for_window_update_get(self):
        """Test case for ui_device_wait_for_window_update_get

        Waits for a window content update event to occur.  # noqa: E501
        """
        pass

    def test_ui_device_wait_get(self):
        """Test case for ui_device_wait_get

        Waits for given the condition to be met.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_clear_get(self):
        """Test case for ui_object2_oid_clear_get

        Clears the text content if this object is an editable field.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_click_and_wait_get(self):
        """Test case for ui_object2_oid_click_and_wait_get

        Clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_click_get(self):
        """Test case for ui_object2_oid_click_get

        Clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_dump_get(self):
        """Test case for ui_object2_oid_dump_get

        Dumps the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_find_object_get(self):
        """Test case for ui_object2_oid_find_object_get

        Finds an object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_find_object_post(self):
        """Test case for ui_object2_oid_find_object_post

        Finds an object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_get_child_count_get(self):
        """Test case for ui_object2_oid_get_child_count_get

        Returns the number of child elements directly under this object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_get_children_get(self):
        """Test case for ui_object2_oid_get_children_get

        """
        pass

    def test_ui_object2_oid_get_content_description_get(self):
        """Test case for ui_object2_oid_get_content_description_get

        Returns the content description for this object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_get_text_get(self):
        """Test case for ui_object2_oid_get_text_get

        Gets the text content.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_long_click_get(self):
        """Test case for ui_object2_oid_long_click_get

        Long-clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_set_text_get(self):
        """Test case for ui_object2_oid_set_text_get

        Sets the text content if this object is an editable field.  # noqa: E501
        """
        pass

    def test_ui_object2_oid_set_text_post(self):
        """Test case for ui_object2_oid_set_text_post

        Sets the text content if this object is an editable field.  # noqa: E501
        """
        pass

    def test_ui_object_oid_clear_text_field_get(self):
        """Test case for ui_object_oid_clear_text_field_get

        Clears the existing text contents in an editable field.  # noqa: E501
        """
        pass

    def test_ui_object_oid_click_and_wait_for_new_window_get(self):
        """Test case for ui_object_oid_click_and_wait_for_new_window_get

        Clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object_oid_click_get(self):
        """Test case for ui_object_oid_click_get

        Clicks on the specified object.  # noqa: E501
        """
        pass

    def test_ui_object_oid_dump_get(self):
        """Test case for ui_object_oid_dump_get

        Dumps the specified object.  # noqa: E501
        """
        pass

    def test_ui_object_oid_exists_get(self):
        """Test case for ui_object_oid_exists_get

        This basically returns immediately whether the view represented by this UiObject exists or not. If you need to wait longer for this view, then see waitForExists.  # noqa: E501
        """
        pass

    def test_ui_object_oid_get_child_count_get(self):
        """Test case for ui_object_oid_get_child_count_get

        Counts the child views immediately under the present UiObject.  # noqa: E501
        """
        pass

    def test_ui_object_oid_get_class_name_get(self):
        """Test case for ui_object_oid_get_class_name_get

        Retrieves the className property of the UI element.  # noqa: E501
        """
        pass

    def test_ui_object_oid_get_content_description_get(self):
        """Test case for ui_object_oid_get_content_description_get

        Reads the content_desc property of the UI element.  # noqa: E501
        """
        pass

    def test_ui_object_oid_perform_two_pointer_gesture_post(self):
        """Test case for ui_object_oid_perform_two_pointer_gesture_post

        """
        pass

    def test_ui_object_oid_pinch_in_get(self):
        """Test case for ui_object_oid_pinch_in_get

        """
        pass

    def test_ui_object_oid_pinch_out_get(self):
        """Test case for ui_object_oid_pinch_out_get

        """
        pass

    def test_ui_object_oid_wait_for_exists_get(self):
        """Test case for ui_object_oid_wait_for_exists_get

        This method waits until the view becomes visible on the display, or until the timeout has elapsed. You can use this method in situations where the content that you want to select is not immediately displayed.  # noqa: E501
        """
        pass

    def test_until_find_object_get(self):
        """Test case for until_find_object_get

        Returns a SearchCondition that is satisfied when at least one element matching the selector can be found.  # noqa: E501
        """
        pass

    def test_until_find_object_post(self):
        """Test case for until_find_object_post

        Returns a SearchCondition that is satisfied when at least one element matching the selector can be found.  # noqa: E501
        """
        pass

    def test_until_find_objects_get(self):
        """Test case for until_find_objects_get

        Returns a SearchCondition that is satisfied when at least one element matching the selector can be found.  # noqa: E501
        """
        pass

    def test_until_find_objects_post(self):
        """Test case for until_find_objects_post

        Returns a SearchCondition that is satisfied when at least one element matching the selector can be found.  # noqa: E501
        """
        pass

    def test_until_new_window_get(self):
        """Test case for until_new_window_get

        Returns a condition that depends on a new window having appeared.  # noqa: E501
        """
        pass

    def test_until_oid_dump_get(self):
        """Test case for until_oid_dump_get

        Dumps the specified object.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import culebratester_client
from culebratester_client.models.point import Point  # noqa: E501
from culebratester_client.rest import ApiException


class TestPoint(unittest.TestCase):
    """Point unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPoint(self):
        """Test Point"""
        # FIXME: construct object with mandatory attributes with example values
        # model = culebratester_client.models.point.Point()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WindowHierarchyChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'parent': 'int',
        'text': 'str',
        'package': 'str',
        'checkable': 'bool',
        'clickable': 'bool',
        'index': 'int',
        'content_description': 'str',
        'focusable': 'bool',
        'resource_id': 'str',
        'enabled': 'bool',
        'password': 'bool',
        'long_clickable': 'bool',
        'long_text': 'str',
        'clazz': 'str',
        'scrollable': 'bool',
        'selected': 'bool',
        'checked': 'bool',
        'focused': 'bool',
        'bounds': 'list[int]',
        'children': 'list[WindowHierarchyChild]'
    }

    attribute_map = {
        'id': 'id',
        'parent': 'parent',
        'text': 'text',
        'package': 'package',
        'checkable': 'checkable',
        'clickable': 'clickable',
        'index': 'index',
        'content_description': 'contentDescription',
        'focusable': 'focusable',
        'resource_id': 'resourceId',
        'enabled': 'enabled',
        'password': 'password',
        'long_clickable': 'longClickable',
        'long_text': 'longText',
        'clazz': 'clazz',
        'scrollable': 'scrollable',
        'selected': 'selected',
        'checked': 'checked',
        'focused': 'focused',
        'bounds': 'bounds',
        'children': 'children'
    }

    def __init__(self, id=None, parent=None, text=None, package=None, checkable=None, clickable=None, index=None, content_description=None, focusable=None, resource_id=None, enabled=None, password=None, long_clickable=None, long_text=None, clazz=None, scrollable=None, selected=None, checked=None, focused=None, bounds=None, children=None):  # noqa: E501
        """WindowHierarchyChild - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._parent = None
        self._text = None
        self._package = None
        self._checkable = None
        self._clickable = None
        self._index = None
        self._content_description = None
        self._focusable = None
        self._resource_id = None
        self._enabled = None
        self._password = None
        self._long_clickable = None
        self._long_text = None
        self._clazz = None
        self._scrollable = None
        self._selected = None
        self._checked = None
        self._focused = None
        self._bounds = None
        self._children = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if parent is not None:
            self.parent = parent
        if text is not None:
            self.text = text
        if package is not None:
            self.package = package
        if checkable is not None:
            self.checkable = checkable
        if clickable is not None:
            self.clickable = clickable
        if index is not None:
            self.index = index
        if content_description is not None:
            self.content_description = content_description
        if focusable is not None:
            self.focusable = focusable
        if resource_id is not None:
            self.resource_id = resource_id
        if enabled is not None:
            self.enabled = enabled
        if password is not None:
            self.password = password
        if long_clickable is not None:
            self.long_clickable = long_clickable
        if long_text is not None:
            self.long_text = long_text
        if clazz is not None:
            self.clazz = clazz
        if scrollable is not None:
            self.scrollable = scrollable
        if selected is not None:
            self.selected = selected
        if checked is not None:
            self.checked = checked
        if focused is not None:
            self.focused = focused
        if bounds is not None:
            self.bounds = bounds
        if children is not None:
            self.children = children

    @property
    def id(self):
        """Gets the id of this WindowHierarchyChild.  # noqa: E501


        :return: The id of this WindowHierarchyChild.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WindowHierarchyChild.


        :param id: The id of this WindowHierarchyChild.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def parent(self):
        """Gets the parent of this WindowHierarchyChild.  # noqa: E501


        :return: The parent of this WindowHierarchyChild.  # noqa: E501
        :rtype: int
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this WindowHierarchyChild.


        :param parent: The parent of this WindowHierarchyChild.  # noqa: E501
        :type: int
        """

        self._parent = parent

    @property
    def text(self):
        """Gets the text of this WindowHierarchyChild.  # noqa: E501


        :return: The text of this WindowHierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this WindowHierarchyChild.


        :param text: The text of this WindowHierarchyChild.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def package(self):
        """Gets the package of this WindowHierarchyChild.  # noqa: E501


        :return: The package of this WindowHierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._package

    @package.setter
    def package(self, package):
        """Sets the package of this WindowHierarchyChild.


        :param package: The package of this WindowHierarchyChild.  # noqa: E501
        :type: str
        """

        self._package = package

    @property
    def checkable(self):
        """Gets the checkable of this WindowHierarchyChild.  # noqa: E501


        :return: The checkable of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._checkable

    @checkable.setter
    def checkable(self, checkable):
        """Sets the checkable of this WindowHierarchyChild.


        :param checkable: The checkable of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._checkable = checkable

    @property
    def clickable(self):
        """Gets the clickable of this WindowHierarchyChild.  # noqa: E501


        :return: The clickable of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._clickable

    @clickable.setter
    def clickable(self, clickable):
        """Sets the clickable of this WindowHierarchyChild.


        :param clickable: The clickable of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._clickable = clickable

    @property
    def index(self):
        """Gets the index of this WindowHierarchyChild.  # noqa: E501


        :return: The index of this WindowHierarchyChild.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this WindowHierarchyChild.


        :param index: The index of this WindowHierarchyChild.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def content_description(self):
        """Gets the content_description of this WindowHierarchyChild.  # noqa: E501


        :return: The content_description of this WindowHierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._content_description

    @content_description.setter
    def content_description(self, content_description):
        """Sets the content_description of this WindowHierarchyChild.


        :param content_description: The content_description of this WindowHierarchyChild.  # noqa: E501
        :type: str
        """

        self._content_description = content_description

    @property
    def focusable(self):
        """Gets the focusable of this WindowHierarchyChild.  # noqa: E501


        :return: The focusable of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._focusable

    @focusable.setter
    def focusable(self, focusable):
        """Sets the focusable of this WindowHierarchyChild.


        :param focusable: The focusable of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._focusable = focusable

    @property
    def resource_id(self):
        """Gets the resource_id of this WindowHierarchyChild.  # noqa: E501


        :return: The resource_id of this WindowHierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this WindowHierarchyChild.


        :param resource_id: The resource_id of this WindowHierarchyChild.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def enabled(self):
        """Gets the enabled of this WindowHierarchyChild.  # noqa: E501


        :return: The enabled of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this WindowHierarchyChild.


        :param enabled: The enabled of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def password(self):
        """Gets the password of this WindowHierarchyChild.  # noqa: E501


        :return: The password of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this WindowHierarchyChild.


        :param password: The password of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._password = password

    @property
    def long_clickable(self):
        """Gets the long_clickable of this WindowHierarchyChild.  # noqa: E501


        :return: The long_clickable of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._long_clickable

    @long_clickable.setter
    def long_clickable(self, long_clickable):
        """Sets the long_clickable of this WindowHierarchyChild.


        :param long_clickable: The long_clickable of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._long_clickable = long_clickable

    @property
    def long_text(self):
        """Gets the long_text of this WindowHierarchyChild.  # noqa: E501


        :return: The long_text of this WindowHierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._long_text

    @long_text.setter
    def long_text(self, long_text):
        """Sets the long_text of this WindowHierarchyChild.


        :param long_text: The long_text of this WindowHierarchyChild.  # noqa: E501
        :type: str
        """

        self._long_text = long_text

    @property
    def clazz(self):
        """Gets the clazz of this WindowHierarchyChild.  # noqa: E501


        :return: The clazz of this WindowHierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._clazz

    @clazz.setter
    def clazz(self, clazz):
        """Sets the clazz of this WindowHierarchyChild.


        :param clazz: The clazz of this WindowHierarchyChild.  # noqa: E501
        :type: str
        """

        self._clazz = clazz

    @property
    def scrollable(self):
        """Gets the scrollable of this WindowHierarchyChild.  # noqa: E501


        :return: The scrollable of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._scrollable

    @scrollable.setter
    def scrollable(self, scrollable):
        """Sets the scrollable of this WindowHierarchyChild.


        :param scrollable: The scrollable of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._scrollable = scrollable

    @property
    def selected(self):
        """Gets the selected of this WindowHierarchyChild.  # noqa: E501


        :return: The selected of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._selected

    @selected.setter
    def selected(self, selected):
        """Sets the selected of this WindowHierarchyChild.


        :param selected: The selected of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._selected = selected

    @property
    def checked(self):
        """Gets the checked of this WindowHierarchyChild.  # noqa: E501


        :return: The checked of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._checked

    @checked.setter
    def checked(self, checked):
        """Sets the checked of this WindowHierarchyChild.


        :param checked: The checked of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._checked = checked

    @property
    def focused(self):
        """Gets the focused of this WindowHierarchyChild.  # noqa: E501


        :return: The focused of this WindowHierarchyChild.  # noqa: E501
        :rtype: bool
        """
        return self._focused

    @focused.setter
    def focused(self, focused):
        """Sets the focused of this WindowHierarchyChild.


        :param focused: The focused of this WindowHierarchyChild.  # noqa: E501
        :type: bool
        """

        self._focused = focused

    @property
    def bounds(self):
        """Gets the bounds of this WindowHierarchyChild.  # noqa: E501


        :return: The bounds of this WindowHierarchyChild.  # noqa: E501
        :rtype: list[int]
        """
        return self._bounds

    @bounds.setter
    def bounds(self, bounds):
        """Sets the bounds of this WindowHierarchyChild.


        :param bounds: The bounds of this WindowHierarchyChild.  # noqa: E501
        :type: list[int]
        """

        self._bounds = bounds

    @property
    def children(self):
        """Gets the children of this WindowHierarchyChild.  # noqa: E501


        :return: The children of this WindowHierarchyChild.  # noqa: E501
        :rtype: list[WindowHierarchyChild]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this WindowHierarchyChild.


        :param children: The children of this WindowHierarchyChild.  # noqa: E501
        :type: list[WindowHierarchyChild]
        """

        self._children = children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WindowHierarchyChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WindowHierarchyChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "culebratester-client"
VERSION = "2.0.62"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="CulebraTester",
    author_email="",
    url="http://github.com/dtmilano/CulebraTester2-client",
    keywords=["Swagger", "CulebraTester"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using &#x60;adb&#x60; - the server should have been started using &#x60;./culebratester2 start-server&#x60;  then you will be able to invoke the API and see the responses.   # noqa: E501
    """
)



# coding: utf-8

"""
    CulebraTester

    ## Snaky Android Test --- If you want to be able to try out the API using the **Execute** or **TRY** button from this page - an android device should be connected using `adb` - the server should have been started using `./culebratester2 start-server`  then you will be able to invoke the API and see the responses.   # noqa: E501

    OpenAPI spec version: 2.0.62
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Selector(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'checkable': 'bool',
        'checked': 'bool',
        'clazz': 'str',
        'clickable': 'bool',
        'depth': 'int',
        'desc': 'str',
        'has_child': 'Selector',
        'pkg': 'str',
        'res': 'str',
        'scrollable': 'bool',
        'text': 'str',
        'index': 'int',
        'instance': 'int'
    }

    attribute_map = {
        'checkable': 'checkable',
        'checked': 'checked',
        'clazz': 'clazz',
        'clickable': 'clickable',
        'depth': 'depth',
        'desc': 'desc',
        'has_child': 'hasChild',
        'pkg': 'pkg',
        'res': 'res',
        'scrollable': 'scrollable',
        'text': 'text',
        'index': 'index',
        'instance': 'instance'
    }

    def __init__(self, checkable=None, checked=None, clazz=None, clickable=None, depth=None, desc=None, has_child=None, pkg=None, res=None, scrollable=None, text=None, index=None, instance=None):  # noqa: E501
        """Selector - a model defined in Swagger"""  # noqa: E501
        self._checkable = None
        self._checked = None
        self._clazz = None
        self._clickable = None
        self._depth = None
        self._desc = None
        self._has_child = None
        self._pkg = None
        self._res = None
        self._scrollable = None
        self._text = None
        self._index = None
        self._instance = None
        self.discriminator = None
        if checkable is not None:
            self.checkable = checkable
        if checked is not None:
            self.checked = checked
        if clazz is not None:
            self.clazz = clazz
        if clickable is not None:
            self.clickable = clickable
        if depth is not None:
            self.depth = depth
        if desc is not None:
            self.desc = desc
        if has_child is not None:
            self.has_child = has_child
        if pkg is not None:
            self.pkg = pkg
        if res is not None:
            self.res = res
        if scrollable is not None:
            self.scrollable = scrollable
        if text is not None:
            self.text = text
        if index is not None:
            self.index = index
        if instance is not None:
            self.instance = instance

    @property
    def checkable(self):
        """Gets the checkable of this Selector.  # noqa: E501


        :return: The checkable of this Selector.  # noqa: E501
        :rtype: bool
        """
        return self._checkable

    @checkable.setter
    def checkable(self, checkable):
        """Sets the checkable of this Selector.


        :param checkable: The checkable of this Selector.  # noqa: E501
        :type: bool
        """

        self._checkable = checkable

    @property
    def checked(self):
        """Gets the checked of this Selector.  # noqa: E501


        :return: The checked of this Selector.  # noqa: E501
        :rtype: bool
        """
        return self._checked

    @checked.setter
    def checked(self, checked):
        """Sets the checked of this Selector.


        :param checked: The checked of this Selector.  # noqa: E501
        :type: bool
        """

        self._checked = checked

    @property
    def clazz(self):
        """Gets the clazz of this Selector.  # noqa: E501


        :return: The clazz of this Selector.  # noqa: E501
        :rtype: str
        """
        return self._clazz

    @clazz.setter
    def clazz(self, clazz):
        """Sets the clazz of this Selector.


        :param clazz: The clazz of this Selector.  # noqa: E501
        :type: str
        """

        self._clazz = clazz

    @property
    def clickable(self):
        """Gets the clickable of this Selector.  # noqa: E501


        :return: The clickable of this Selector.  # noqa: E501
        :rtype: bool
        """
        return self._clickable

    @clickable.setter
    def clickable(self, clickable):
        """Sets the clickable of this Selector.


        :param clickable: The clickable of this Selector.  # noqa: E501
        :type: bool
        """

        self._clickable = clickable

    @property
    def depth(self):
        """Gets the depth of this Selector.  # noqa: E501


        :return: The depth of this Selector.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this Selector.


        :param depth: The depth of this Selector.  # noqa: E501
        :type: int
        """

        self._depth = depth

    @property
    def desc(self):
        """Gets the desc of this Selector.  # noqa: E501


        :return: The desc of this Selector.  # noqa: E501
        :rtype: str
        """
        return self._desc

    @desc.setter
    def desc(self, desc):
        """Sets the desc of this Selector.


        :param desc: The desc of this Selector.  # noqa: E501
        :type: str
        """

        self._desc = desc

    @property
    def has_child(self):
        """Gets the has_child of this Selector.  # noqa: E501


        :return: The has_child of this Selector.  # noqa: E501
        :rtype: Selector
        """
        return self._has_child

    @has_child.setter
    def has_child(self, has_child):
        """Sets the has_child of this Selector.


        :param has_child: The has_child of this Selector.  # noqa: E501
        :type: Selector
        """

        self._has_child = has_child

    @property
    def pkg(self):
        """Gets the pkg of this Selector.  # noqa: E501


        :return: The pkg of this Selector.  # noqa: E501
        :rtype: str
        """
        return self._pkg

    @pkg.setter
    def pkg(self, pkg):
        """Sets the pkg of this Selector.


        :param pkg: The pkg of this Selector.  # noqa: E501
        :type: str
        """

        self._pkg = pkg

    @property
    def res(self):
        """Gets the res of this Selector.  # noqa: E501


        :return: The res of this Selector.  # noqa: E501
        :rtype: str
        """
        return self._res

    @res.setter
    def res(self, res):
        """Sets the res of this Selector.


        :param res: The res of this Selector.  # noqa: E501
        :type: str
        """

        self._res = res

    @property
    def scrollable(self):
        """Gets the scrollable of this Selector.  # noqa: E501


        :return: The scrollable of this Selector.  # noqa: E501
        :rtype: bool
        """
        return self._scrollable

    @scrollable.setter
    def scrollable(self, scrollable):
        """Sets the scrollable of this Selector.


        :param scrollable: The scrollable of this Selector.  # noqa: E501
        :type: bool
        """

        self._scrollable = scrollable

    @property
    def text(self):
        """Gets the text of this Selector.  # noqa: E501


        :return: The text of this Selector.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Selector.


        :param text: The text of this Selector.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def index(self):
        """Gets the index of this Selector.  # noqa: E501


        :return: The index of this Selector.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this Selector.


        :param index: The index of this Selector.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def instance(self):
        """Gets the instance of this Selector.  # noqa: E501


        :return: The instance of this Selector.  # noqa: E501
        :rtype: int
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this Selector.


        :param instance: The instance of this Selector.  # noqa: E501
        :type: int
        """

        self._instance = instance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Selector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Selector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
